@@ -91,8 +91,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
 
     private:
-        template <typename T, typename Q>
-        T resourcesByPackageNames(const Q& names) const;
+        template <typename T>
+        T resourcesByPackageNames(const QStringList& names) const;
         void fetchUpdates();
 
         void checkDaemonRunning();
